(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     97689,       2277]*)
(*NotebookOutlinePosition[     98400,       2301]*)
(*  CellTagsIndexPosition[     98356,       2297]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["JLinkProgramming`JavaSwing`JavaSwing`", "Title"],

Cell["Junzo Sato", "Subtitle"],

Cell["\<\
Copyright \[Copyright] 2000-2001, Junzo Sato. All rights reserved.

Junzo Sato
Email: <jsato@fc.kuh.kumamoto-u.ac.jp>\
\>", "Text"],

Cell[CellGroupData[{

Cell["Annotation", "Section"],

Cell[BoxData[
    \(\(\( (*\ \(:\)\(Title : \ 
          JavaSwing\)\ *) \)\(\[IndentingNewLine]\)\( (*\ \(:\)\(Context : \ 
          JLinkProgramming`JavaSwing`JavaSwing`\)\ *) \)\(\n\)\( (*\ \
\(:\)\(Author : \ Junzo\ SATO\)\ *) \)\(\n\)\( (*\ \(:\)\(Summary : \ 
          This\ package\ provides\ wrapper\ functions\ to\ use\ JavaSwing\ \
components\ within\ \(\(MATHEMATICA\)\(.\)\)\)\ *) \)\(\n\)\( (*\ \
\(:\)\(Package\ \(Version : \ 
            1.1  .2\)\)\ *) \)\(\n\)\( (*\ \(:\)\(Release\ \(Note : \
\[IndentingNewLine]Ver\ 1.0\ Sep\ 2000\ for\ JLink\ 1.0  \
.1\[IndentingNewLine]
          Ver\ 1.1\ Feb\ 2001\ for\ JLink\ 1.1  .2\[IndentingNewLine]
          
          Ver\ 1.1  .1\ Sep\ 2001\ for\ JLinkProgramming`JLinkSupport` . \
\[IndentingNewLine]Reproduced\ with\ Mathematica\ 4.1\ in\ Jul\ 2001\ \
\[IndentingNewLine]
          
          Ver\ 1.1  .2\ Oct\ 2001\ NewJInternalFrame\ is\ modified\ to\ make\ \
it\ \(\(visible\)\(.\)\)\)\)\ *) \)\(\n\)\( (*\ \(:\)\(Mathematica\ \(Version \
: \ 4.1\)\)\ *) \)\(\n\)\( (*\ \(\(:\)\(Copyright : \ 
          Copyright\ \[Copyright]\ 2000 - 2001\)\), \ 
      Junzo\ Sato . \ 
          All\ rights\ \(\(reserved\)\(.\)\)\ *) \)\(\n\)\( (*\ \
\(:\)\(History : \[IndentingNewLine]Ver\ 1.0\ Sep\ 2000\ for\ JLink\ 1.0  .1\
\[IndentingNewLine]
        Ver\ 1.1\ Feb\ 2001\ for\ JLink\ 1.1  .2\)\ *) \)\(\n\)\( (*\ \(\(:\)\
\(Keywords : \ Java\)\), \ Swing, \ 
      JavaSwing\ *) \)\(\n\)\( (*\ \(\(:\)\(Reference : \ \([1]\)\ "\<Pure \
JFC Swing\>"\ by\ Satyaraj\ Pantham\)\), \ 1999, \ 
      Sams\ Publishing\ *) \)\(\n\)\( (*\ \(:\)\(\(Limitation\)\(:\)\)\ *) \)\
\(\n\)\( (*\ \(:\)\(\(Discussion\)\(:\)\)\ *) \)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Print["\<Loading JavaSwing...\>"]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Beginning of Package", "Section"],

Cell[BoxData[
    \(BeginPackage["\<JLinkProgramming`JavaSwing`JavaSwing`\>", \
{"\<JLink`\>", "\<JLinkProgramming`JLinkSupport`\>"}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(InstallJAVA[]\)], "Input",
  InitializationCell->True],

Cell["\<\
Java classes used in this package are preloaded so that we can save \
execution time of each method in them.
Of course, this requires more memories for some methods which the user would \
not use.\
\>", "Text"],

Cell[BoxData[{
    \(\(LoadClass["\<java.lang.Thread\>"];\)\), "\n", 
    \(\(LoadClass["\<java.lang.String\>"];\)\), "\n", 
    \(\(\(LoadClass["\<java.lang.Character\>"];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(LoadClass["\<com.wolfram.jlink.MathJFrame\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(\(LoadClass["\<com.wolfram.jlink.MathActionListener\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<java.awt.Toolkit\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<java.awt.BorderLayout\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<java.awt.FlowLayout\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<java.awt.Color\>"];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<java.awt.event.ActionEvent\>"];\)\(\[IndentingNewLine]\
\)
    \)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.ImageIcon\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.SwingConstants\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JDesktopPane\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JInternalFrame\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JSplitPane\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JTabbedPane\>"];\)\), "\[IndentingNewLine]", \

    \(\(LoadClass["\<javax.swing.JLabel\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JPanel\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.border.EmptyBorder\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.border.EtchedBorder\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.border.BevelBorder\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.border.SoftBevelBorder\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.border.MatteBorder\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.border.LineBorder\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.border.CompoundBorder\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.border.TitledBorder\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JButton\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JToggleButton\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JCheckBox\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JRadioButton\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.plaf.basic.BasicArrowButton\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JList\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JComboBox\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JTable\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JTextField\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JPasswordField\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JTextArea\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JEditorPane\>"];\)\), "\[IndentingNewLine]", \

    \(\(LoadClass["\<javax.swing.JTextPane\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JScrollBar\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.ScrollPaneConstants\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JScrollPane\>"];\)\), "\[IndentingNewLine]", \

    \(\(LoadClass["\<javax.swing.JSlider\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JMenuBar\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JMenu\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JMenuItem\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JCheckBoxMenuItem\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JRadioButtonMenuItem\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JToolBar\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JOptionPane\>"];\)\), "\[IndentingNewLine]", \

    \(\(LoadClass["\<javax.swing.JFileChooser\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JColorChooser\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JProgressBar\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JFrame\>"];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.SwingUtilities\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.ProgressMonitor\>"];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Unprotect[Evaluate[$Context <> "\<*\>"]]\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Path for sample images.", "Subsubsection"],

Cell[BoxData[
    \($JavaSwingMaterial := 
      StringJoin[\[IndentingNewLine]Switch[$OperatingSystem, \
\[IndentingNewLine]"\<Unix\>", \[IndentingNewLine]$TopDirectory, \
\[IndentingNewLine]"\<MacOS\>", \[IndentingNewLine]StringJoin["\</\>", 
            StringReplace[$TopDirectory, "\<:\>" \[Rule] "\</\>"]], \
\[IndentingNewLine]_, \[IndentingNewLine]If[
            StringMatchQ[$OperatingSystem, "\<Windows*\>"], \
\[IndentingNewLine]StringReplace[$TopDirectory, {"\<C:\\\>" \[Rule] "\</\>", \
"\<\\\>" -> "\</\>"}], \[IndentingNewLine]$TopDirectory]\[IndentingNewLine]], \
\[IndentingNewLine]"\</AddOns/Applications/JLinkProgramming/JavaSwing/\
Material/\>"]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Usage", "Subsubsection"],

Cell[BoxData[
    StyleBox[\(\(SleepThread::usage = "\<nothing\>";\)\[IndentingNewLine]
      \(FindChar::usage = "\<nothing\>";\)\[IndentingNewLine]
      \(GiMeDaChar::usage = "\<nothing\>";\)\[IndentingNewLine]
      \(GetCharAsString::usage = "\<nothing\>";\)\),
      FontColor->RGBColor[0, 0, 1]]], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(DeleteJObject::usage = "\<\!\(\*
StyleBox[\"DeleteJObject\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"container\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"obj\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"doRepaint\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)removes the \!\(\*
StyleBox[\"obj\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)from \!\(\*
StyleBox[\(the\*
StyleBox[\"container\",\nFontWeight->\"Bold\"]\)]\). If \!\(\*
StyleBox[\"doRepaint\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)is set to \!\(\*
StyleBox[\"True\",\nFontWeight->\"Bold\"]\), the container is repainted. \
Then,the \!\(\*
StyleBox[\"obj\",\nFontWeight->\"Bold\"]\) is released.\>"; \)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewMathJFrame::usage = "\<NewMathJFrame[title,w,h,x,y] creates a \
MathJFrame object with specified titile,set the location of the frame to \
{x,y},and resize the frame to {w,h}.Where {x,y} is the top left corner of the \
frame on the current graphics coordinates and {w,h} is {width,height} of the \
frame. By default, {x, y} is {0, 0}.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(CenterizeFrameOnScreen::usage = "\<CenterizeFrameOnScreen[frame] \
locates the frame to the center of the main screen.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewImageIcon::usage = "\<NewImageIcon[path] creates an ImageIcon from \
the specified file.\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(swTop::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swLeft::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swBottom::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swRight::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swNorth::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swNorthEast::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swEast::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swSouthEast::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swSouth::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swSouthWest::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swWest::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swNothWest::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swCenter::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swHorizontal::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(swVertical::usage = "\<nothing\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewJDesktopPane::usage = "\<nothing\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewJInternalFrame::usage = "\<nothing\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NewJSplitPane::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJTabbedPane::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJLabel::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJPanelEmptyBorder::usage = "\<nothing\>";\)\), \
"\[IndentingNewLine]", 
    \(\(NewJPanelEtchedBorder::usage = "\<nothing\>";\)\), "\
\[IndentingNewLine]", 
    \(\(NewJPanelBevelBorder::usage = "\<nothing\>";\)\), \
"\[IndentingNewLine]", 
    \(\(NewJPanelSoftBevelBorder::usage = "\<nothing\>";\)\), "\
\[IndentingNewLine]", 
    \(\(NewJPanelMatteBorder::usage = "\<nothing\>";\)\), \
"\[IndentingNewLine]", 
    \(\(NewJPanelMatteBorderTileIcon::usage = "\<nothing\>";\)\), "\
\[IndentingNewLine]", 
    \(\(NewJPanelLineBorder::usage = "\<nothing\>";\)\), \
"\[IndentingNewLine]", 
    \(\(NewJPanelCompoundBorder::usage = "\<nothing\>";\)\), "\
\[IndentingNewLine]", 
    \(\(NewJPanelTitledBorder::usage = "\<nothing\>";\)\), "\
\[IndentingNewLine]", 
    \(\(NewJButton::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJToggleButton::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJCheckBox::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJRadioButton::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewBasicArrowButton::usage = "\<nothing\>";\)\), \
"\[IndentingNewLine]", 
    \(\(NewJList::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJComboBox::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJTable::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJTextField::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJPasswordField::usage = "\<nothing\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NewJTextArea::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(JTextAreaInsert::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(JTextAreaDelete::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(JTextAreaCut::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(JTextAreaCopy::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(JTextAreaPaste::usage = "\<nothing\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NewJEditorPane::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJTextPane::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJScrollBar::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJScrollPane::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJSlider::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJMenuBar::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJMenu::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJMenuItem::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(NewJCheckBoxMenuItem::usage = "\<nothing\>";\)\), \
"\[IndentingNewLine]", 
    \(\(NewJRadioButtonMenuItem::usage = "\<nothing\>";\)\), "\
\[IndentingNewLine]", 
    \(\(NewJToolBar::usage = "\<nothing\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(ShowMessageDialog::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", \

    \(\(ShowConfirmDialog::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", \

    \(\(ShowInputDialog::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(ShowFileChooser::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(GetFilePathAndName::usage = "\<nothing\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(NewJColorChooser::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(ShowColorChooser::usage = "\<nothing\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(NewJTree::usage = "\<nothing\>";\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(ShowProgressBar::usage = "\<nothing\>";\)\), "\[IndentingNewLine]", 
    \(\(DestroyProgressBar::usage = "\<nothing\>";\)\), \
"\[IndentingNewLine]", 
    \(\(ShowProgressMonitor::usage = "\<nothing\>";\)\), \
"\[IndentingNewLine]", 
    \(\(DestroyProgressMonitor::usage = "\<nothing\>";\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Begin["\<`Private`\>"]\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tools", "Section",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell["SleepThread", "Subsection",
  InitializationCell->True,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(SleepThread[msec_] := 
      JavaBlock[
        Module[\[IndentingNewLine]{}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]LoadClass["\<java.lang.Thread\>"]; \
\[IndentingNewLine]java`lang`Thread`currentThread[]@
            sleep[msec];\[IndentingNewLine]]]\)], "Input",
  InitializationCell->True,
  FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindChar", "Subsection",
  FontColor->RGBColor[0, 0, 1]],

Cell["\<\
(*
\tThis implementation is obsolete. New definition is created by the help of \
Todd.
*
FindChar[x_:\"\"]:=Module[
    {tbl,pos},
    tbl={{\" \
\",32},{\"!\",33},{\"\\\"\",34},{\"#\",35},{\"$\",36},{\"%\",37},{\"&\",38},{\
\"'\",39},{\"(\",40},{\")\",41},{\"*\",42},{\"+\",43},{\",\",44},{\"-\",45},{\
\".\",46},{\"/\",47},{\"0\",48},{\"1\",49},{\"2\",50},{\"3\",51},{\"4\",52},{\
\"5\",53},{\"6\",54},{\"7\",55},{\"8\",56},{\"9\",57},{\":\",58},{\";\",59},{\
\"<\",60},{\"=\",61},{\">\",62},{\"?\",63},{\"@\",64},{\"A\",65},{\"B\",66},{\
\"C\",67},{\"D\",68},{\"E\",69},{\"F\",70},{\"G\",71},{\"H\",72},{\"I\",73},{\
\"J\",74},{\"K\",75},{\"L\",76},{\"M\",77},{\"N\",78},{\"O\",79},{\"P\",80},{\
\"Q\",81},{\"R\",82},{\"S\",83},{\"T\",84},{\"U\",85},{\"V\",86},{\"W\",87},{\
\"X\",88},{\"Y\",89},{\"Z\",90},{\"[\",91},{\"\[Backslash]\",92},{\"]\",93},{\
\"^\",94},{\"_\",95},{\"`\",96},{\"a\",97},{\"b\",98},{\"c\",99},{\"d\",100},{\
\"e\",101},{\"f\",102},{\"g\",103},{\"h\",104},{\"i\",105},{\"j\",106},{\"k\",\
107},{\"l\",108},{\"m\",109},{\"n\",110},{\"o\",111},{\"p\",112},{\"q\",113},{\
\"r\",114},{\"s\",115},{\"t\",116},{\"u\",117},{\"v\",118},{\"w\",119},{\"x\",\
120},{\"y\",121},{\"z\",122},{\"{\",123},{\"|\",124},{\"}\",125},{\"~\",126}};\

    If[x=!=\"\",
      pos=Position[tbl,x][[1]];
      tbl[[#1,#2]]&@@{pos[[1]],If[pos[[2]]===1,2,1]},
      Null]
    ]\
\>", "Text",
  InitializationCell->True,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(FindChar[x_: "\<\>"] := 
      If[Head[x] === String, \[IndentingNewLine]First[
          ToCharacterCode[x]], \[IndentingNewLine]FromCharacterCode[
          x]]\)], "Input",
  InitializationCell->True,
  FontColor->RGBColor[0, 0, 1]]
}, Closed]],

Cell[CellGroupData[{

Cell["GiMeDaChar", "Subsection",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(GiMeDaChar[str_, at_Integer:  0] := 
      Module[\[IndentingNewLine]{charObj, 
          strObj}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]strObj = 
          JavaNew["\<java.lang.String\>", str]; \[IndentingNewLine]charObj = 
          JavaNew["\<java.lang.Character\>", 
            strObj@charAt[at]]; \[IndentingNewLine]ReleaseObject[
          strObj]; \[IndentingNewLine]Return[
          charObj]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True,
  FontColor->RGBColor[0, 0, 1]]
}, Closed]],

Cell[CellGroupData[{

Cell["GetCharAsString", "Subsection",
  FontColor->RGBColor[0, 0, 1]],

Cell["\<\
GetCharAsString[
\tByRef[JLinkApplet`CJLinkApplet`passChar[FindChar[\"K\"]]]
]\
\>", "Text",
  InitializationCell->True,
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(GetCharAsString[ref_] := 
      JavaBlock[
        Module[\[IndentingNewLine]{str}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]str = 
            JavaNew["\<java.lang.String\>", 
              ref@toString[]]; \[IndentingNewLine]Return[
            Val[str]]\[IndentingNewLine]]]\)], "Input",
  InitializationCell->True,
  FontColor->RGBColor[0, 0, 1]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Removing Components", "Section"],

Cell["\<\
DeleteJObject[container ,obj ,doRepaint] removes an obj from the \
container. If doRepaint is True, it sends repaint() message to the container.\
\
\>", "Text"],

Cell[BoxData[
    \(DeleteJObject[container_, obj_, doRepaint_:  True] := 
      JavaBlock[
        Module[\[IndentingNewLine]{}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]container@remove[obj]; \[IndentingNewLine]If[
            doRepaint === True, \[IndentingNewLine]container@
              repaint[]\[IndentingNewLine]]; \[IndentingNewLine]ReleaseObject[
            obj];\[IndentingNewLine]]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> com.wolfram.jlink.MathJFrame <<<", "Section"],

Cell[BoxData[{
    \(\(\(NewMathJFrame[
        title_String: "\<MathJFrame\>", \[IndentingNewLine]w_:  0, h_:  0, 
        x_:  0, y_:  0] := 
      Module[\[IndentingNewLine]{frame}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]frame = 
          JavaNew["\<com.wolfram.jlink.MathJFrame\>", 
            title]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]frame@
            setLocation[x, y]; \[IndentingNewLine]If[
            w > 0 && h > 0, \[IndentingNewLine]frame@
              setSize[w, 
                h]\[IndentingNewLine]];\[IndentingNewLine]]; \
\[IndentingNewLine]Return[frame]\[IndentingNewLine]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(CenterizeFrameOnScreen[frame_] := 
      JavaBlock[
        Module[\[IndentingNewLine]{screen, size, newX, 
            newY}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]LoadClass["\<java.awt.Toolkit\>"]; \
\[IndentingNewLine]screen = 
            java`awt`Toolkit`getDefaultToolkit[]@
              getScreenSize[]; \[IndentingNewLine]size = 
            frame@getSize[]; \[IndentingNewLine]newX = 
            Round[\((screen@width - size@width)\)/
                2]; \[IndentingNewLine]newY = 
            Round[\((screen@height - size@height)\)/
                2]; \[IndentingNewLine]frame@
            setLocation[newX, newY];\[IndentingNewLine]]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.ImageIcon <<<", "Section"],

Cell[BoxData[
    \(NewImageIcon[path_:  Null] := 
      Module[\[IndentingNewLine]{icon}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]icon = 
          JavaNew["\<javax.swing.ImageIcon\>", 
            path]; \[IndentingNewLine]Return[
          icon]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.SwingConstants <<<", "Section"],

Cell[BoxData[
    \(LoadClass["\<javax.swing.SwingConstants\>"]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swTop = javax`swing`SwingConstants`TOP\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swLeft = javax`swing`SwingConstants`LEFT\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swBottom = javax`swing`SwingConstants`BOTTOM\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swRight = javax`swing`SwingConstants`RIGHT\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swNorth = javax`swing`SwingConstants`NORTH\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swNorthEast = javax`swing`SwingConstants`NORTHUEAST\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swEast = javax`swing`SwingConstants`EAST\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swSouthEast = javax`swing`SwingConstants`SOUTHUEAST\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swSouth = javax`swing`SwingConstants`SOUTH\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swSouthWest = javax`swing`SwingConstants`SOUTHUWEST\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swWest = javax`swing`SwingConstants`WEST\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swNothWest = javax`swing`SwingConstants`NORTHUWEST\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swCenter = javax`swing`SwingConstants`CENTER\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swHorizontal = javax`swing`SwingConstants`HORIZONTAL\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(swVertical = javax`swing`SwingConstants`VERTICAL\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JDesktopPane <<<", "Section"],

Cell[BoxData[
    \(NewJDesktopPane[
        container_:  
          Null, \[IndentingNewLine]tip_String: "\<JDesktopPane\>"] := 
      Module[\[IndentingNewLine]{desktop}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]desktop = 
          JavaNew["\<javax.swing.JDesktopPane\>"]; \
\[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[desktop]\[IndentingNewLine]]; \[IndentingNewLine]desktop@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          desktop]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JInternalFrame <<<", "Section"],

Cell[BoxData[
    \(NewJInternalFrame[
        container_:  Null, \[IndentingNewLine]layerConst_:  
          Null, \[IndentingNewLine]title_String: "\<JInternalFrame\>", \
\[IndentingNewLine]x_:  0, y_:  0, width_:  0, 
        height_:  0, \[IndentingNewLine]resizable_:  
          True, \[IndentingNewLine]closable_:  
          True, \[IndentingNewLine]maximizable_:  
          True, \[IndentingNewLine]iconifiable_:  
          True, \[IndentingNewLine]icon_:  
          Null, \[IndentingNewLine]tip_String: "\<JInternalFrame\>"] := 
      Module[\[IndentingNewLine]{frame}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]frame = 
          JavaNew["\<javax.swing.JInternalFrame\>", \[IndentingNewLine]title, 
            resizable, closable, maximizable, 
            iconifiable]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            layerConst =!= Null, \[IndentingNewLine]If[
              container\  =!= \ Null, \[IndentingNewLine]container@
                add[frame, 
                  layerConst]\[IndentingNewLine]], \[IndentingNewLine]If[
              container\  =!= \ Null, \[IndentingNewLine]container@
                add[frame]\[IndentingNewLine]]\[IndentingNewLine]]; \
\[IndentingNewLine]frame@setLocation[x, y]; \[IndentingNewLine]If[
            width > 0 && height > 0, \[IndentingNewLine]frame@
              setSize[width, 
                height]\[IndentingNewLine]]; \[IndentingNewLine]If[
            icon =!= Null, \[IndentingNewLine]frame@
              setFrameIcon[
                icon]\[IndentingNewLine]]; \[IndentingNewLine]frame@
            setToolTipText[tip]; \[IndentingNewLine]frame@
            setVisible[True];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          frame]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JSplitPane <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.JSplitPane\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJSplitPane[
        container_:  Null, \[IndentingNewLine]orientation_:  
          javax`swing`JSplitPane`VERTICALUSPLIT, \
\[IndentingNewLine]continuous_:  True, \[IndentingNewLine]dividerSize_:  
          8, \[IndentingNewLine]tip_String: "\<JSplitPane\>"] := 
      Module[\[IndentingNewLine]{split}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]split = 
          JavaNew["\<javax.swing.JSplitPane\>", \
\[IndentingNewLine]orientation, 
            continuous]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[split]\[IndentingNewLine]]; \[IndentingNewLine]split@
            setDividerSize[8]; \[IndentingNewLine]split@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          split]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JTabbedPane <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.JTabbedPane\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJTabbedPane[
        container_:  Null, \[IndentingNewLine]placement_:  
          javax`swing`JTabbedPane`TOP, \[IndentingNewLine]tip_String: \
"\<JTabbedPane\>"] := 
      Module[\[IndentingNewLine]{pane}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]pane = 
          JavaNew["\<javax.swing.JTabbedPane\>", 
            placement]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[pane]\[IndentingNewLine]]; \[IndentingNewLine]pane@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          pane]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JLabel <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.JLabel\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJLabel[
        container_:  
          Null, \[IndentingNewLine]title_String: "\<JLabel\>", \
\[IndentingNewLine]icon_:  Null, \[IndentingNewLine]x_Integer:  0, 
        y_Integer:  0, width_Integer:  0, height_Integer:  0, 
        horizontalAlignment_:  javax`swing`JLabel`CENTER, 
        tip_String: "\<JLabel\>"] := 
      Module[\[IndentingNewLine]{label}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[
          icon =!= Null, \[IndentingNewLine]label = 
            JavaNew["\<javax.swing.JLabel\>", title, icon, 
              horizontalAlignment], \[IndentingNewLine]label = 
            JavaNew["\<javax.swing.JLabel\>", title, 
              horizontalAlignment]\[IndentingNewLine]]; \
\[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[label]\[IndentingNewLine]]; \[IndentingNewLine]If[
            width > 0 && height > 0, \[IndentingNewLine]label@
              setBounds[x, y, width, 
                height]\[IndentingNewLine]]; \[IndentingNewLine]label@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          label]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JPanel and border <<<", "Section"],

Cell[CellGroupData[{

Cell["EmptyBorder", "Subsection"],

Cell[BoxData[
    \(NewJPanelEmptyBorder[
        container_:  Null, \[IndentingNewLine]top_Integer:  
          1, \[IndentingNewLine]left_Integer:  
          1, \[IndentingNewLine]bottom_Integer:  
          1, \[IndentingNewLine]right_Integer:  
          1, \[IndentingNewLine]tip_String: "\<JPanel(EmptyBorder)\>", \
\[IndentingNewLine]addLabel_:  False] := 
      Module[\[IndentingNewLine]{panel, border, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \
\[IndentingNewLine]border = 
            JavaNew["\<javax.swing.border.EmptyBorder\>", top, left, bottom, 
              right]; \[IndentingNewLine]\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                border@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[border]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["EtchedBorder", "Subsection"],

Cell[BoxData[
    \(NewJPanelEtchedBorder[
        container_:  Null, \[IndentingNewLine]isRaised_:  
          True, \[IndentingNewLine]highlight_:  Null, 
        shadow_:  
          Null, \[IndentingNewLine]tip_String: "\<JPanel(EtchedBorder)\>", \
\[IndentingNewLine]addLabel_:  False] := 
      Module[\[IndentingNewLine]{panel, border, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \
\[IndentingNewLine]LoadClass["\<javax.swing.border.EtchedBorder\>"]; \
\[IndentingNewLine]etchType = 
            Evaluate[\[IndentingNewLine]If[
                isRaised, \
\[IndentingNewLine]javax`swing`border`EtchedBorder`RAISED, 
                javax`swing`border`EtchedBorder`LOWERED]]; \
\[IndentingNewLine]If[
            highlight =!= Null && 
              shadow =!= Null, \[IndentingNewLine]border = 
              JavaNew["\<javax.swing.border.EtchedBorder\>", \
\[IndentingNewLine]etchType, highlight, shadow], \[IndentingNewLine]border = 
              JavaNew["\<javax.swing.border.EtchedBorder\>", \
\[IndentingNewLine]etchType]]; \[IndentingNewLine]\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                border@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[border]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["BevelBorder", "Subsection"],

Cell[BoxData[
    \(NewJPanelBevelBorder[container_:  Null, 
        isRaised_:  True, \[IndentingNewLine]highlightOuter_:  Null, 
        highlightInner_:  Null, \[IndentingNewLine]shadowOuter_:  Null, 
        shadowInner_:  
          Null, \[IndentingNewLine]tip_String: "\<JPanel(BevelBorder)\>", \
\[IndentingNewLine]addLabel_:  False] := 
      Module[\[IndentingNewLine]{panel, border, bevelType, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \[IndentingNewLine]\
\[IndentingNewLine]LoadClass["\<javax.swing.border.BevelBorder\>"]; \
\[IndentingNewLine]bevelType = 
            Evaluate[\[IndentingNewLine]If[
                isRaised, \
\[IndentingNewLine]javax`swing`border`BevelBorder`RAISED, 
                javax`swing`border`BevelBorder`LOWERED]]; \[IndentingNewLine]\
\[IndentingNewLine]If[
            highlightOuter =!= Null && 
              highlightInner =!= Null, \[IndentingNewLine]If[
              shadowOuter =!= Null && 
                shadowInner =!= Null, \[IndentingNewLine]border = 
                JavaNew[\[IndentingNewLine]"\<javax.swing.border.BevelBorder\>\
", \[IndentingNewLine]bevelType, highlightOuter, 
                  highlightInner, \[IndentingNewLine]shadowOuter, 
                  shadowInner\[IndentingNewLine]], \[IndentingNewLine]border \
= JavaNew[\[IndentingNewLine]"\<javax.swing.border.BevelBorder\>", \
\[IndentingNewLine]bevelType, highlightOuter, 
                  highlightInner\[IndentingNewLine]]\[IndentingNewLine]], \
\[IndentingNewLine]border = 
              JavaNew[\[IndentingNewLine]"\<javax.swing.border.BevelBorder\>",\
 \[IndentingNewLine]bevelType\[IndentingNewLine]]\[IndentingNewLine]]; \
\[IndentingNewLine]\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                border@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[border]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["SoftBevelBorder", "Subsection"],

Cell[BoxData[{
    \(\(Needs["\<JLink`\>"];\)\), "\[IndentingNewLine]", 
    \(NewJPanelSoftBevelBorder[container_:  Null, 
        isRaised_:  True, \[IndentingNewLine]highlightOuter_:  Null, 
        highlightInner_:  Null, \[IndentingNewLine]shadowOuter_:  Null, 
        shadowInner_:  
          Null, \[IndentingNewLine]tip_String: "\<JPanel(SoftBevelBorder)\>", \
\[IndentingNewLine]addLabel_:  False] := 
      Module[\[IndentingNewLine]{panel, border, bevelType, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \[IndentingNewLine]\
\[IndentingNewLine]LoadClass["\<javax.swing.border.SoftBevelBorder\>"]; \
\[IndentingNewLine]bevelType = 
            Evaluate[\[IndentingNewLine]If[
                isRaised, \
\[IndentingNewLine]javax`swing`border`SoftBevelBorder`RAISED, 
                javax`swing`border`SoftBevelBorder`LOWERED]]; \
\[IndentingNewLine]\[IndentingNewLine]If[
            highlightOuter =!= Null && 
              highlightInner =!= Null, \[IndentingNewLine]If[
              shadowOuter =!= Null && 
                shadowInner =!= Null, \[IndentingNewLine]border = 
                JavaNew[\[IndentingNewLine]"\<javax.swing.border.\
SoftBevelBorder\>", \[IndentingNewLine]bevelType, highlightOuter, 
                  highlightInner, \[IndentingNewLine]shadowOuter, 
                  shadowInner\[IndentingNewLine]], \[IndentingNewLine]border \
= JavaNew[\[IndentingNewLine]"\<javax.swing.border.SoftBevelBorder\>", \
\[IndentingNewLine]bevelType, highlightOuter, 
                  highlightInner\[IndentingNewLine]]\[IndentingNewLine]], \
\[IndentingNewLine]border = 
              JavaNew[\[IndentingNewLine]"\<javax.swing.border.\
SoftBevelBorder\>", \[IndentingNewLine]bevelType\[IndentingNewLine]]\
\[IndentingNewLine]]; \[IndentingNewLine]\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                border@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[border]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["MatteBorder", "Subsection"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\n", 
    \(\(\(LoadClass["\<java.awt.Color\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(NewJPanelMatteBorder[container_:  Null, \[IndentingNewLine]top_:  4, 
        left_:  4, bottom_:  4, right_:  4, 
        color_:  
          java`awt`Color`gray, \[IndentingNewLine]tip_String: \
"\<JPanel(MatteBorder)\>", \[IndentingNewLine]addLabel_:  False] := 
      Module[\[IndentingNewLine]{panel, border, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \[IndentingNewLine]\
\[IndentingNewLine]border = 
            JavaNew["\<javax.swing.border.MatteBorder\>", top, left, bottom, 
              right, color]; \[IndentingNewLine]\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                border@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[border]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(NewJPanelMatteBorderTileIcon[container_:  Null, 
        titleIcon_:  
          Null, \[IndentingNewLine]tip_String: "\<JPanel(MatteBorder)\>", \
\[IndentingNewLine]addLabel_:  False] := 
      Module[\[IndentingNewLine]{panel, border, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \[IndentingNewLine]\
\[IndentingNewLine]border = 
            JavaNew["\<javax.swing.border.MatteBorder\>", 
              titleIcon]; \[IndentingNewLine]\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                border@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[border]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["LineBorder", "Subsection"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<java.awt.Color\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJPanelLineBorder[container_:  Null, thickness_:  1, 
        color_:  java`awt`Color`gray, 
        tip_String: "\<JPanel(LineBorder)\>", \[IndentingNewLine]addLabel_:  
          False] := Module[\[IndentingNewLine]{panel, border, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \
\[IndentingNewLine]border = 
            JavaNew["\<javax.swing.border.LineBorder\>", color, 
              thickness]; \[IndentingNewLine]\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                border@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[border]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["CompoundBorder", "Subsection"],

Cell[BoxData[
    \(NewJPanelCompoundBorder[container_:  Null, outsideBorder_:  Null, 
        insideBorder_:  Null, 
        tip_String: "\<JPanel(CompoundBorder)\>", \
\[IndentingNewLine]addLabel_:  False] := 
      Module[\[IndentingNewLine]{panel, border, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \[IndentingNewLine]If[
            outsideBorder =!= Null && 
              insideBorder =!= Null, \[IndentingNewLine]border = 
              JavaNew[\[IndentingNewLine]"\<javax.swing.border.CompoundBorder\
\>", outsideBorder, insideBorder], \[IndentingNewLine]border = 
              JavaNew[\[IndentingNewLine]"\<javax.swing.border.CompoundBorder\
\>"]\[IndentingNewLine]]; \[IndentingNewLine]\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                border@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[border]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["TitledBorder", "Subsection"],

Cell[BoxData[
    \(NewJPanelTitledBorder[
        container_:  
          Null, \[IndentingNewLine]title_String: "\<Title\>", \
\[IndentingNewLine]border_:  
          Null, \[IndentingNewLine]tip_String: "\<JPanel(TitledBorder)\>", \
\[IndentingNewLine]addLabel_:  False] := 
      Module[\[IndentingNewLine]{panel, titledBorder, string, name, 
          label}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]panel \
= JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]panel@
            setLayout[
              JavaNew["\<java.awt.BorderLayout\>"]]; \[IndentingNewLine]If[
            border =!= Null, \[IndentingNewLine]titledBorder = 
              JavaNew["\<javax.swing.border.TitledBorder\>", border, 
                title], \[IndentingNewLine]titledBorder = 
              JavaNew["\<javax.swing.border.TitledBorder\>", 
                title]\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]If[
            addLabel, \[IndentingNewLine]string = 
              JavaNew["\<java.lang.String\>", 
                titledBorder@\(getClass[]@toString[]\)]; 
            name = string@
                substring[
                  string@lastIndexOf["\<.\>"] + 
                    1]; \[IndentingNewLine]LoadClass["\<javax.swing.JLabel\>"]\
; \[IndentingNewLine]label = 
              JavaNew["\<javax.swing.JLabel\>", name, 
                javax`swing`JLabel`CENTER]; \[IndentingNewLine]panel@
              add[label];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@setBorder[titledBorder]; \[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[panel]; \[IndentingNewLine]container@
              repaint[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]panel@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          panel]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JButton <<<", "Section"],

Cell[BoxData[
    \(NewJButton[
        container_:  
          Null, \[IndentingNewLine]title_String: "\<JButton\>", \
\[IndentingNewLine]icon_:  Null, \[IndentingNewLine]x_Integer:  0, 
        y_Integer:  0, width_Integer:  0, height_Integer:  0, 
        tip_String: "\<JButton\>"] := 
      Module[\[IndentingNewLine]{button}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[
          icon =!= Null, \[IndentingNewLine]button = 
            JavaNew["\<javax.swing.JButton\>", title, 
              icon], \[IndentingNewLine]button = 
            JavaNew["\<javax.swing.JButton\>", 
              title]\[IndentingNewLine]]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[button]\[IndentingNewLine]]; \[IndentingNewLine]If[
            width > 0 && height > 0, \[IndentingNewLine]button@
              setBounds[x, y, width, 
                height]\[IndentingNewLine]]; \[IndentingNewLine]button@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          button]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JToggleButton <<<", "Section"],

Cell[BoxData[
    \(NewJToggleButton[
        container_:  
          Null, \[IndentingNewLine]title_String: "\<JToggleButton\>", \
\[IndentingNewLine]selected_:  False, \[IndentingNewLine]icon_:  
          Null, \[IndentingNewLine]x_Integer:  0, y_Integer:  0, 
        width_Integer:  0, height_Integer:  0, 
        tip_String: "\<JToggleButton\>"] := 
      Module[\[IndentingNewLine]{button}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[icon =!= Null, 
          button = 
            JavaNew["\<javax.swing.JToggleButton\>", title, icon, 
              selected], \[IndentingNewLine]button = 
            JavaNew["\<javax.swing.JToggleButton\>", title, 
              selected]\[IndentingNewLine]]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[button]\[IndentingNewLine]]; \[IndentingNewLine]If[
            width > 0 && height > 0, \[IndentingNewLine]button@
              setBounds[x, y, width, 
                height]\[IndentingNewLine]]; \[IndentingNewLine]button@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          button]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JCheckBox <<<", "Section"],

Cell[BoxData[
    \(NewJCheckBox[
        container_:  
          Null, \[IndentingNewLine]title_String: "\<JCheckBox\>", \
\[IndentingNewLine]selected_:  False, \[IndentingNewLine]icon_:  
          Null, \[IndentingNewLine]x_Integer:  0, y_Integer:  0, 
        width_Integer:  0, height_Integer:  0, tip_String: "\<JCheckBox\>"] := 
      Module[\[IndentingNewLine]{button}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[
          icon =!= Null, \[IndentingNewLine]button = 
            JavaNew["\<javax.swing.JCheckBox\>", title, icon, 
              selected], \[IndentingNewLine]button = 
            JavaNew["\<javax.swing.JCheckBox\>", title, 
              selected]\[IndentingNewLine]]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[button]\[IndentingNewLine]]; \[IndentingNewLine]If[
            width > 0 && height > 0, \[IndentingNewLine]button@
              setBounds[x, y, width, 
                height]\[IndentingNewLine]]; \[IndentingNewLine]button@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          button]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JRadioButton <<<", "Section"],

Cell[BoxData[
    \(NewJRadioButton[
        container_:  
          Null, \[IndentingNewLine]title_String: "\<JRadioButton\>", \
\[IndentingNewLine]selected_:  False, \[IndentingNewLine]icon_:  
          Null, \[IndentingNewLine]x_Integer:  0, y_Integer:  0, 
        width_Integer:  0, height_Integer:  0, 
        tip_String: "\<JRadioButton\>"] := 
      Module[\[IndentingNewLine]{button}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[
          icon =!= Null, \[IndentingNewLine]button = 
            JavaNew["\<javax.swing.JRadioButton\>", title, icon, 
              selected], \[IndentingNewLine]button = 
            JavaNew["\<javax.swing.JRadioButton\>", title, 
              selected]\[IndentingNewLine]]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[button]\[IndentingNewLine]]; \[IndentingNewLine]If[
            width > 0 && height > 0, \[IndentingNewLine]button@
              setBounds[x, y, width, 
                height]\[IndentingNewLine]]; \[IndentingNewLine]button@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          button]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.plaf.basic.BasicArrowButton <<<", "Section"],

Cell[BoxData[
    \(NewBasicArrowButton[container_:  Null, direction_Integer, 
        x_Integer:  0, y_Integer:  0, width_Integer:  20, 
        height_Integer:  20, tip_String: "\<BasicArrowButton\>"] := 
      Module[\[IndentingNewLine]{button}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]button = 
          JavaNew["\<javax.swing.plaf.basic.BasicArrowButton\>", 
            direction]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[button]\[IndentingNewLine]]; \[IndentingNewLine]button@
            setBounds[x, y, width, height]; \[IndentingNewLine]button@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          button]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JList <<<", "Section"],

Cell[BoxData[
    \(NewJList[
        container_:  Null, \[IndentingNewLine]data_:  
          Null, \[IndentingNewLine]tip_String: "\<JList\>"] := 
      Module[\[IndentingNewLine]{list}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]list = 
          JavaNew["\<javax.swing.JList\>", 
            data]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container =!= Null, \[IndentingNewLine]container@
              add[list]\[IndentingNewLine]]; \[IndentingNewLine]list@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          list]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JComboBox <<<", "Section"],

Cell[BoxData[
    \(NewJComboBox[
        container_:  Null, \[IndentingNewLine]items_:  
          Null, \[IndentingNewLine]tip_String: "\<JComboBox\>"] := 
      Module[\[IndentingNewLine]{box}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]box = 
          JavaNew["\<javax.swing.JComboBox\>", 
            items]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container =!= Null, \[IndentingNewLine]container@
              add[box]\[IndentingNewLine]]; \[IndentingNewLine]box@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          box]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JTable <<<", "Section"],

Cell[BoxData[
    \(NewJTable[container_:  Null, \[IndentingNewLine]rowData_, 
        columnNames_, \[IndentingNewLine]tip_String: "\<JComboBox\>"] := 
      Module[\[IndentingNewLine]{table}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]table = 
          JavaNew["\<javax.swing.JTable\>", rowData, 
            columnNames]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]LoadClass["\<java.awt.BorderLayout\>"];\
 \[IndentingNewLine]container@
              add[\[IndentingNewLine]table@
                  getTableHeader[], \
\[IndentingNewLine]JavaNew["\<java.lang.String\>", 
                  java`awt`BorderLayout`NORTH]\[IndentingNewLine]]; \
\[IndentingNewLine]container@
              add[table];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]table@
            setColumnSelectionAllowed[True]; \[IndentingNewLine]table@
            setCellSelectionEnabled[
              True]; \[IndentingNewLine]\[IndentingNewLine]table@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          table]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JTextField <<<", "Section"],

Cell[BoxData[
    \(NewJTextField[
        container_:  
          Null, \[IndentingNewLine]text_: "\<\>", \
\[IndentingNewLine]columns_:  0, \[IndentingNewLine]doc_:  
          Null, \[IndentingNewLine]tip_String: "\<JTextField\>"] := 
      Module[\[IndentingNewLine]{field}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[doc =!= Null, 
          field = JavaNew["\<javax.swing.JTextField\>", doc, text, 
              columns], \[IndentingNewLine]field = 
            JavaNew["\<javax.swing.JTextField\>", text, 
              columns]\[IndentingNewLine]]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]\(container@
                add[field];\)\[IndentingNewLine]]; \[IndentingNewLine]field@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          field]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JPasswordField <<<", "Section"],

Cell[BoxData[
    \(NewJPasswordField[
        container_:  
          Null, \[IndentingNewLine]text_: "\<\>", \
\[IndentingNewLine]columns_:  0, \[IndentingNewLine]doc_:  
          Null, \[IndentingNewLine]tip_String: "\<JPasswordField\>"] := 
      Module[\[IndentingNewLine]{field}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[
          doc =!= Null, \[IndentingNewLine]field = 
            JavaNew["\<javax.swing.JPasswordField\>", doc, text, 
              columns], \[IndentingNewLine]field = 
            JavaNew["\<javax.swing.JPasswordField\>", text, 
              columns]\[IndentingNewLine]]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]\(container@
                add[field];\)\[IndentingNewLine]]; \[IndentingNewLine]field@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          field]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JTextArea <<<", "Section"],

Cell[BoxData[
    \(NewJTextArea[
        container_:  
          Null, \[IndentingNewLine]text_: "\<\>", \[IndentingNewLine]rows_:  
          0, \[IndentingNewLine]columns_:  0, \[IndentingNewLine]doc_:  
          Null, \[IndentingNewLine]tip_String: "\<JTextArea\>"] := 
      Module[\[IndentingNewLine]{area}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[
          doc =!= Null, \[IndentingNewLine]area = 
            JavaNew["\<javax.swing.JTextArea\>", doc, text, rows, 
              columns], \[IndentingNewLine]area = 
            JavaNew["\<javax.swing.JTextArea\>", text, rows, 
              columns]\[IndentingNewLine]]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]\(container@
                add[area];\)\[IndentingNewLine]]; \[IndentingNewLine]area@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          area]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(JTextAreaInsert[textArea_, text_] := 
      Module[\[IndentingNewLine]{}, \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]textArea@
            insert[text, 
              textArea@
                getCaretPosition[]]\[IndentingNewLine]]\[IndentingNewLine]]\)]\
, "Input",
  InitializationCell->True],

Cell[BoxData[
    \(JTextAreaDelete[textArea_] := 
      Module[\[IndentingNewLine]{}, \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]textArea@
            replaceSelection["\<\>"]\[IndentingNewLine]]\[IndentingNewLine]]\)\
], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(JTextAreaCut[textArea_] := 
      Module[\[IndentingNewLine]{}, \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]textArea@
            cut[]\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(JTextAreaCopy[textArea_] := 
      Module[\[IndentingNewLine]{}, \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]textArea@
            copy[]\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(JTextAreaPaste[textArea_] := 
      Module[\[IndentingNewLine]{}, \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]textArea@
            paste[]\[IndentingNewLine]]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JEditorPane <<<", "Section"],

Cell[BoxData[
    \(NewJEditorPane[
        container_:  Null, \[IndentingNewLine]url_:  
          Null, \[IndentingNewLine]tip_String: "\<JEditorPane\>"] := 
      Module[\[IndentingNewLine]{editor}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[url =!= Null, 
          editor = 
            JavaNew["\<javax.swing.JEditorPane\>", 
              url], \[IndentingNewLine]editor = 
            JavaNew["\<javax.swing.JEditorPane\>"]\[IndentingNewLine]]; \
\[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]\(container@
                add[editor];\)\[IndentingNewLine]]; \[IndentingNewLine]editor@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          editor]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JTextPane <<<", "Section"],

Cell[BoxData[
    \(NewJTextPane[
        container_:  Null, \[IndentingNewLine]doc_:  
          Null, \[IndentingNewLine]tip_String: "\<JTextPane\>"] := 
      Module[\[IndentingNewLine]{textPane}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[doc =!= Null, 
          textPane = 
            JavaNew["\<javax.swing.JTextPane\>", 
              doc], \[IndentingNewLine]textPane = 
            JavaNew["\<javax.swing.JTextPane\>"]\[IndentingNewLine]]; \
\[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]\(container@
                add[textPane];\)\[IndentingNewLine]]; \
\[IndentingNewLine]textPane@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          textPane]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JScrollBar <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.JScrollBar\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJScrollBar[
        container_:  Null, \[IndentingNewLine]orientation_:  
          javax`swing`JScrollBar`VERTICAL, \[IndentingNewLine]value_:  0, 
        extent_:  10, minimum_:  0, 
        maximum_:  100, \[IndentingNewLine]tip_String: "\<JScrollBar\>"] := 
      Module[\[IndentingNewLine]{bar}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]bar = 
          JavaNew["\<javax.swing.JScrollBar\>", \
\[IndentingNewLine]orientation, value, extent, minimum, 
            maximum]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]\(container@
                add[bar];\)\[IndentingNewLine]]; \[IndentingNewLine]bar@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          bar]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JScrollPane <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.ScrollPaneConstants\>"];\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJScrollPane[
        container_:  Null, \[IndentingNewLine]view_:  
          Null, \[IndentingNewLine]vsbPolicy_:  
          javax`swing`ScrollPaneConstants`VERTICALUSCROLLBARUASUNEEDED, \
\[IndentingNewLine]hsbPolicy_:  
          javax`swing`ScrollPaneConstants`HORIZONTALUSCROLLBARUASUNEEDED, \
\[IndentingNewLine]tip_String: "\<JScrollPane\>"] := 
      Module[\[IndentingNewLine]{pane}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]If[
          view =!= Null, \[IndentingNewLine]pane = 
            JavaNew["\<javax.swing.JScrollPane\>", \[IndentingNewLine]view, 
              vsbPolicy, hsbPolicy], \[IndentingNewLine]pane = 
            JavaNew["\<javax.swing.JScrollPane\>", \
\[IndentingNewLine]vsbPolicy, 
              hsbPolicy]\[IndentingNewLine]]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[pane]\[IndentingNewLine]]; \[IndentingNewLine]pane@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          pane]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JSlider <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.JSlider\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJSlider[
        container_:  Null, \[IndentingNewLine]orientation_:  
          javax`swing`JSlider`HORIZONTAL, \[IndentingNewLine]min_:  0, 
        max_:  100, 
        value_:  50, \[IndentingNewLine]doPaintTicks_:  
          True, \[IndentingNewLine]majorTickSpacing_:  
          10, \[IndentingNewLine]minorTickSpacing_:  
          2, \[IndentingNewLine]labelIncrement_:  
          10, \[IndentingNewLine]tip_String: "\<JSlider\>"] := 
      Module[\[IndentingNewLine]{slider}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]slider = 
          JavaNew["\<javax.swing.JSlider\>", \[IndentingNewLine]orientation, 
            min, max, 
            value]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]\(container@
                add[slider];\)\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]slider@
            setPaintTicks[doPaintTicks]; \[IndentingNewLine]slider@
            setMajorTickSpacing[majorTickSpacing]; \[IndentingNewLine]slider@
            setMinorTickSpacing[
              minorTickSpacing]; \[IndentingNewLine]\[IndentingNewLine]If[
            labelIncrement > 0, \[IndentingNewLine]slider@
              setLabelTable[
                slider@createStandardLabels[
                    labelIncrement]]; \[IndentingNewLine]slider@
              setPaintLabels[
                True];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]slider@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          slider]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JMenuBar <<<", "Section"],

Cell[BoxData[
    \(NewJMenuBar[frame_:  Null] := 
      Module[\[IndentingNewLine]{menubar}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]menubar = 
          JavaNew["\<javax.swing.JMenuBar\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]LoadClass["\<javax.swing.border.BevelBorder\>"]; \
\[IndentingNewLine]menubar@
            setBorder[
              JavaNew["\<javax.swing.border.BevelBorder\>", 
                javax`swing`border`BevelBorder`RAISED]]; \
\[IndentingNewLine]menubar@setBorderPainted[True]; \[IndentingNewLine]If[
            frame =!= Null, 
            frame@setJMenuBar[
                menubar]];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          menubar]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JMenu <<<", "Section"],

Cell[BoxData[
    \(NewJMenu[menubar_:  Null, \[IndentingNewLine]title_: "\<JMenu\>", 
        mnemonic_: "\<\>", enabled_:  True] := 
      Module[\[IndentingNewLine]{menu}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]menu = 
          JavaNew["\<javax.swing.JMenu\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]menu@setText[title]; \[IndentingNewLine]menu@
            setEnabled[enabled]; \[IndentingNewLine]If[mnemonic =!= "\<\>", 
            menu@setMnemonic[FindChar[mnemonic]]]; \[IndentingNewLine]If[
            menubar =!= Null, 
            menubar@add[
                menu]];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          menu]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JMenuItem <<<", "Section"],

Cell[BoxData[
    \(NewJMenuItem[menu_:  Null, \[IndentingNewLine]title_: "\<JMenuItem\>", 
        mnemonic_: "\<\>", enabled_:  True] := 
      Module[\[IndentingNewLine]{item}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]item = 
          JavaNew["\<javax.swing.JMenuItem\>"]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]item@setText[title]; \[IndentingNewLine]item@
            setEnabled[enabled]; \[IndentingNewLine]If[mnemonic =!= "\<\>", 
            item@setMnemonic[FindChar[mnemonic]]]; \[IndentingNewLine]If[
            menu =!= Null, 
            menu@add[item]];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          item]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JCheckBoxMenuItem <<<", "Section"],

Cell[BoxData[
    \(NewJCheckBoxMenuItem[
        menu_:  Null, \[IndentingNewLine]title_: "\<JCheckBoxMenuItem\>", 
        mnemonic_: "\<\>", checked_:  False, enabled_:  True] := 
      Module[\[IndentingNewLine]{item}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]item = 
          JavaNew["\<javax.swing.JCheckBoxMenuItem\>"]; \
\[IndentingNewLine]JavaBlock[\[IndentingNewLine]item@
            setText[title]; \[IndentingNewLine]item@
            setState[checked]; \[IndentingNewLine]item@
            setEnabled[enabled]; \[IndentingNewLine]If[mnemonic =!= "\<\>", 
            item@setMnemonic[FindChar[mnemonic]]]; \[IndentingNewLine]If[
            menu =!= Null, 
            menu@add[item]];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          item]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JRadioButtonMenuItem <<<", "Section"],

Cell[BoxData[
    \(NewJRadioButtonMenuItem[
        menu_:  Null, \[IndentingNewLine]title_: "\<JRadioButtonMenuItem\>", 
        mnemonic_: "\<\>", enabled_:  True] := 
      Module[\[IndentingNewLine]{item}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]item = 
          JavaNew["\<javax.swing.JRadioButtonMenuItem\>"]; \
\[IndentingNewLine]JavaBlock[\[IndentingNewLine]item@
            setText[title]; \[IndentingNewLine]item@
            setEnabled[enabled]; \[IndentingNewLine]If[mnemonic =!= "\<\>", 
            item@setMnemonic[FindChar[mnemonic]]]; \[IndentingNewLine]If[
            menu =!= Null, 
            menu@add[item]];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          item]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[">>> javax.swing.JPopupMenu <<<", "Section"],

Cell[CellGroupData[{

Cell[">>> javax.swing.JToolBar <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(LoadClass["\<javax.swing.JToolBar\>"];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<java.awt.BorderLayout\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJToolBar[
        container_:  Null, \[IndentingNewLine]orientation_:  
          javax`swing`JToolBar`HORIZONTAL, \[IndentingNewLine]floatable_:  
          True, \[IndentingNewLine]layout_:  
          java`awt`BorderLayout`NORTH, \[IndentingNewLine]tip_String: \
"\<JToolBar\>"] := 
      Module[\[IndentingNewLine]{bar}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]bar = 
          JavaNew["\<javax.swing.JToolBar\>", 
            orientation]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]bar@
            setFloatable[floatable]; \[IndentingNewLine]If[
            container =!= 
              Null, \[IndentingNewLine]\(container@
                add[bar, 
                  JavaNew["\<java.lang.String\>", 
                    layout]];\)\[IndentingNewLine]]; \[IndentingNewLine]bar@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          bar]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JOptionPane <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.JOptionPane\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(ShowMessageDialog[
        parent_:  Null, \[IndentingNewLine]message_:  
          Null, \[IndentingNewLine]options_:  
          Null, \[IndentingNewLine]title_: "\<Message\>", \
\[IndentingNewLine]messageType_:  
          javax`swing`JOptionPane`INFORMATIONUMESSAGE, \
\[IndentingNewLine]optionType_:  
          javax`swing`JOptionPane`DEFAULTUOPTION, \[IndentingNewLine]icon_:  
          Null, \[IndentingNewLine]tip_String: "\<JOptionPane\>"] := 
      JavaBlock[
        Module[\[IndentingNewLine]{option, 
            dialog}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]option = 
            JavaNew["\<javax.swing.JOptionPane\>", \
\[IndentingNewLine]message, messageType, optionType, icon, 
              options]; \[IndentingNewLine]option@
            setToolTipText[tip]; \[IndentingNewLine]If[
            ClassName[
                parent] === "\<com.wolfram.jlink.MathJFrame\>", \
\[IndentingNewLine]JavaShow[
              parent]\[IndentingNewLine]]; \[IndentingNewLine]dialog = 
            option@createDialog[parent, title]; \[IndentingNewLine]dialog@
            show[];\[IndentingNewLine]]]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.JOptionPane\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(ShowConfirmDialog[
        parent_:  Null, \[IndentingNewLine]message_:  
          Null, \[IndentingNewLine]optionType_:  
          javax`swing`JOptionPane`YESUNOUOPTION, \[IndentingNewLine]title_: "\
\<Question\>", \[IndentingNewLine]messageType_:  
          javax`swing`JOptionPane`QUESTIONUMESSAGE, \[IndentingNewLine]icon_: 
           Null] := 
      Module[\[IndentingNewLine]{result = $Failed}, \
\[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            ClassName[
                parent] === "\<com.wolfram.jlink.MathJFrame\>", \
\[IndentingNewLine]JavaShow[
              parent]\[IndentingNewLine]]; \[IndentingNewLine]result = 
            javax`swing`JOptionPane`showConfirmDialog[parent, message, title, 
              optionType, messageType, 
              icon];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          result]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.JOptionPane\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(ShowInputDialog[
        parent_:  Null, \[IndentingNewLine]message_:  
          Null, \[IndentingNewLine]selections_:  
          Null, \[IndentingNewLine]initial_:  
          1, \[IndentingNewLine]title_: "\<Question\>", \
\[IndentingNewLine]messageType_:  
          javax`swing`JOptionPane`QUESTIONUMESSAGE, \[IndentingNewLine]icon_: 
           Null] := 
      Module[\[IndentingNewLine]{result = $Failed}, \
\[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]JavaBlock[\
\[IndentingNewLine]If[
            ClassName[
                parent] === "\<com.wolfram.jlink.MathJFrame\>", \
\[IndentingNewLine]JavaShow[
              parent]\[IndentingNewLine]]; \[IndentingNewLine]If[
            selections =!= Null, 
            result = 
              javax`swing`JOptionPane`showInputDialog[
                parent, \[IndentingNewLine]message, title, messageType, icon, 
                selections, 
                selections[\([initial]\)]], \[IndentingNewLine]result = 
              javax`swing`JOptionPane`showInputDialog[
                parent, \[IndentingNewLine]message]\[IndentingNewLine]];\
\[IndentingNewLine]]; \[IndentingNewLine]Return[
          result]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JFileChooser <<<", "Section"],

Cell[BoxData[
    \(ShowFileChooser[\[IndentingNewLine]title_String: "\<Select a file:\>", \
\[IndentingNewLine]okText_String: "\<Open\>", \[IndentingNewLine]dir_String: \
"\<\>"] := JavaBlock[
        Module[\[IndentingNewLine]{directory = Directory[], dlg, chosenFile, 
            result = 
              Null}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]dlg \
= JavaNew["\<javax.swing.JFileChooser\>"]; \[IndentingNewLine]If[
            dir =!= "\<\>", directory = dir]; \[IndentingNewLine]dlg@
            setCurrentDirectory[
              JavaNew["\<java.io.File\>", directory]]; \[IndentingNewLine]dlg@
            setDialogTitle[title]; \[IndentingNewLine]If[
            dlg@showDialog[Null, okText] === 
              javax`swing`JFileChooser`APPROVEUOPTION, 
            chosenFile = dlg@getSelectedFile[]; \[IndentingNewLine]If[
              chosenFile =!= Null, 
              result = 
                chosenFile@
                  getPath[]]\[IndentingNewLine]]; \[IndentingNewLine]result\
\[IndentingNewLine]]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(GetFilePathAndName[\[IndentingNewLine]title_String: "\<Select a \
file:\>", \[IndentingNewLine]okText_String: "\<Open\>", \
\[IndentingNewLine]dir_String: "\<\>"] := 
      JavaBlock[
        Module[\[IndentingNewLine]{directory = Directory[], dlg, chosenFile, 
            result = 
              Null}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]dlg \
= JavaNew["\<javax.swing.JFileChooser\>"]; \[IndentingNewLine]If[
            dir =!= "\<\>", directory = dir]; \[IndentingNewLine]dlg@
            setCurrentDirectory[
              JavaNew["\<java.io.File\>", directory]]; \[IndentingNewLine]dlg@
            setDialogTitle[title]; \[IndentingNewLine]If[
            dlg@showDialog[Null, okText] === 
              javax`swing`JFileChooser`APPROVEUOPTION, 
            chosenFile = dlg@getSelectedFile[]; \[IndentingNewLine]If[
              chosenFile =!= Null, 
              result = {chosenFile@getPath[], 
                  chosenFile@
                    getName[]}]\[IndentingNewLine]]; \
\[IndentingNewLine]result\[IndentingNewLine]]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JColorChooser <<<", "Section"],

Cell[BoxData[{
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<java.awt.Color\>"];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(NewJColorChooser[
        container_:  Null, \[IndentingNewLine]color_:  
          java`awt`Color`white, \[IndentingNewLine]tip_String: \
"\<JColorChooser\>"] := 
      Module[\[IndentingNewLine]{chooser}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]chooser = 
          JavaNew["\<javax.swing.JColorChooser\>", 
            color]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[chooser]\[IndentingNewLine]]; \[IndentingNewLine]chooser@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          chooser]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{\(InstallJAVA[];\), "\[IndentingNewLine]", 
    RowBox[{\(LoadClass["\<java.awt.Color\>"];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(ShowColorChooser[
        color_:  
          java`awt`Color`black, \[IndentingNewLine]title_: "\<Color \
Chooser\>"]\), ":=", 
      RowBox[{"Module", "[", "\[IndentingNewLine]", 
        RowBox[{\({frm, pane, chooser, panel, \[IndentingNewLine]button1, 
            buttonListener1, buttonFunc1, \[IndentingNewLine]button2, 
            buttonListener2, buttonFunc2, \[IndentingNewLine]button3, 
            buttonListener3, buttonFunc3, \[IndentingNewLine]result = Null}\),
           ",", "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"JavaBlock", "[", "\[IndentingNewLine]", 
              
              RowBox[{\(InstallJAVA[]\), ";", 
                "\[IndentingNewLine]", \
\(LoadClass["\<java.awt.event.ActionEvent\>"]\), ";", "\n", 
                "\[IndentingNewLine]", \(frm = 
                  JavaNew["\<com.wolfram.jlink.MathJFrame\>", title]\), ";", 
                "\[IndentingNewLine]", \(pane = frm@getContentPane[]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \
\(LoadClass["\<javax.swing.BoxLayout\>"]\), ";", 
                "\[IndentingNewLine]", \(pane@
                  setLayout[\[IndentingNewLine]JavaNew["\<javax.swing.\
BoxLayout\>", \[IndentingNewLine]pane, \
\[IndentingNewLine]javax`swing`BoxLayout`YUAXIS]\[IndentingNewLine]]\), ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", \( (**) \), 
                "\[IndentingNewLine]", \(chooser = 
                  NewJColorChooser[pane, color]\), ";", 
                "\[IndentingNewLine]", \(panel = NewJPanelEmptyBorder[pane]\),
                 ";", "\[IndentingNewLine]", \( (**) \), 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(LoadClass["\<java.awt.FlowLayout\>"]\
\), ";", "\[IndentingNewLine]", \(panel@
                  setLayout[
                    JavaNew["\<java.awt.FlowLayout\>", \
\[IndentingNewLine]java`awt`FlowLayout`CENTER, 5, 5]\[IndentingNewLine]]\), 
                ";", 
                StyleBox["\[IndentingNewLine]",
                  FontColor->GrayLevel[0]], \(button1 = 
                  NewJButton[panel, "\<OK\>"]\), ";", 
                "\[IndentingNewLine]", \(button2 = 
                  NewJButton[panel, "\<Cancel\>"]\), ";", 
                "\[IndentingNewLine]", \(button3 = 
                  NewJButton[panel, "\<Reset\>"]\), ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", \( (**) \), 
                "\[IndentingNewLine]", \(buttonListener1 = 
                  JavaNew["\<com.wolfram.jlink.MathActionListener\>"]\), ";", 
                "\[IndentingNewLine]", \(buttonListener1@
                  setHandler["\<actionPerformed\>", ToString[buttonFunc1]]\), 
                ";", "\[IndentingNewLine]", \(button1@
                  addActionListener[buttonListener1]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(buttonListener2 = 
                  JavaNew["\<com.wolfram.jlink.MathActionListener\>"]\), ";", 
                "\[IndentingNewLine]", \(buttonListener2@
                  setHandler["\<actionPerformed\>", ToString[buttonFunc2]]\), 
                ";", "\[IndentingNewLine]", \(button2@
                  addActionListener[buttonListener2]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(buttonListener3 = 
                  JavaNew["\<com.wolfram.jlink.MathActionListener\>"]\), ";", 
                "\[IndentingNewLine]", \(buttonListener3@
                  setHandler["\<actionPerformed\>", ToString[buttonFunc3]]\), 
                ";", "\[IndentingNewLine]", \(button3@
                  addActionListener[buttonListener3]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(buttonFunc1[event_, command_] := 
                  JavaBlock[
                    Module[\[IndentingNewLine]{c = 
                          Null}, \[IndentingNewLine]EndModal[]; \
\[IndentingNewLine]c = chooser@getColor[]; \[IndentingNewLine]If[
                        c =!= $Failed && 
                          c =!= Null, \[IndentingNewLine]result = {c@
                              getRed[], c@getGreen[], 
                            c@getBlue[]}; \[IndentingNewLine]frm@
                          dispose[], \[IndentingNewLine]result = 
                          Null\[IndentingNewLine]]; \
\[IndentingNewLine]ReleaseObject[event];\[IndentingNewLine]]]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(buttonFunc2[event_, command_] := 
                  JavaBlock[
                    Module[\[IndentingNewLine]{}, \
\[IndentingNewLine]EndModal[]; \[IndentingNewLine]result = 
                        Null; \[IndentingNewLine]frm@
                        dispose[]; \[IndentingNewLine]ReleaseObject[
                        event];\[IndentingNewLine]]]\), ";", 
                "\[IndentingNewLine]", 
                "\[IndentingNewLine]", \(buttonFunc3[event_, command_] := 
                  JavaBlock[
                    Module[\[IndentingNewLine]{}, \[IndentingNewLine]chooser@
                        setColor[color]; \[IndentingNewLine]result = 
                        Null; \[IndentingNewLine]ReleaseObject[
                        event];\[IndentingNewLine]]]\), ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", \(frm@pack[]\), 
                ";", "\[IndentingNewLine]", \(JavaShow[frm]\), ";", 
                "\[IndentingNewLine]", \(frm@setModal[]\), ";", 
                "\[IndentingNewLine]", \(DoModal[]\), ";"}], 
              "\[IndentingNewLine]", "]"}], ";", 
            "\[IndentingNewLine]", \(Return[result]\)}]}], 
        "\[IndentingNewLine]", "]"}]}]}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.JTree <<<", "Section"],

Cell[BoxData[
    \(NewJTree[
        container_:  Null, \[IndentingNewLine]rootObj_:  
          Null, \[IndentingNewLine]leafIcon_:  
          Null, \[IndentingNewLine]openIcon_:  
          Null, \[IndentingNewLine]closedIcon_:  
          Null, \[IndentingNewLine]tip_String: "\<JTree\>"] := 
      Module[\[IndentingNewLine]{tree, renderer, h = {}, 
          max}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]If[
          rootObj =!= Null, \[IndentingNewLine]tree = 
            JavaNew["\<javax.swing.JTree\>", 
              rootObj], \[IndentingNewLine]tree = 
            JavaNew["\<javax.swing.JTree\>"]\[IndentingNewLine]]; \
\[IndentingNewLine]JavaBlock[\[IndentingNewLine]If[leafIcon =!= Null, 
            AppendTo[h, leafIcon@getIconHeight[]]]; \[IndentingNewLine]If[
            openIcon =!= Null, 
            AppendTo[h, openIcon@getIconHeight[]]]; \[IndentingNewLine]If[
            closedIcon =!= Null, 
            AppendTo[h, 
              closedIcon@getIconHeight[]]]; \[IndentingNewLine]max = 
            If[{} =!= Select[h, NumberQ], \[IndentingNewLine]Max[
                Select[h, 
                  NumberQ]], \[IndentingNewLine]0]; \[IndentingNewLine]If[
            max > 0, 
            tree@setRowHeight[
                max]]; \[IndentingNewLine]\[IndentingNewLine]renderer = 
            tree@getCellRenderer[]; \[IndentingNewLine]If[leafIcon =!= Null, 
            renderer@setLeafIcon[leafIcon]]; \[IndentingNewLine]If[
            openIcon =!= Null, 
            renderer@setOpenIcon[openIcon]]; \[IndentingNewLine]If[
            closedIcon =!= Null, 
            renderer@
              setClosedIcon[
                closedIcon]]; \[IndentingNewLine]\[IndentingNewLine]If[
            container\  =!= \ Null, \[IndentingNewLine]container@
              add[tree]\[IndentingNewLine]]; \[IndentingNewLine]tree@
            setToolTipText[
              tip];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          tree]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[">>> javax.swing.Timer <<<", "Section"],

Cell[CellGroupData[{

Cell[">>> javax.swing.JProgressBar <<< by jlink@wolfram.com", "Section"],

Cell[BoxData[{
    \(\(\(ShowProgressBar[title_String: "\<Computation Progress\>", 
        caption_String: "\<Percent complete:\>", \
\[IndentingNewLine]percent_Integer:  0] := 
      Module[\[IndentingNewLine]{frame, panel, label, 
          bar}, \[IndentingNewLine]InstallJAVA[]; \[IndentingNewLine]bar = 
          JavaNew["\<javax.swing.JProgressBar\>"]; \
\[IndentingNewLine]JavaBlock[\[IndentingNewLine]frame = 
            JavaNew["\<javax.swing.JFrame\>", 
              title]; \[IndentingNewLine]frame@
            setSize[300, 110]; \[IndentingNewLine]frame@
            setResizable[False]; \[IndentingNewLine]frame@
            setLocation[400, 
              400]; \[IndentingNewLine]\[IndentingNewLine]panel = 
            JavaNew["\<javax.swing.JPanel\>"]; \[IndentingNewLine]panel@
            setLayout[Null]; \[IndentingNewLine]frame@\(getContentPane[]@
              add[panel]\); \[IndentingNewLine]\[IndentingNewLine]label = 
            JavaNew["\<javax.swing.JLabel\>", 
              caption]; \[IndentingNewLine]label@
            setBounds[20, 10, 260, 20]; \[IndentingNewLine]panel@
            add[label]; \[IndentingNewLine]\[IndentingNewLine]bar@
            setBounds[20, 40, 260, 30]; \[IndentingNewLine]bar@
            setMinimum[0]; \[IndentingNewLine]bar@
            setMaximum[100]; \[IndentingNewLine]bar@
            setValue[percent]; \[IndentingNewLine]panel@
            add[bar]; \[IndentingNewLine]\[IndentingNewLine]JavaShow[
            frame]; \[IndentingNewLine]bar\[IndentingNewLine]]\
\[IndentingNewLine]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.SwingUtilities\>"];\)\(\[IndentingNewLine]\
\)
    \)\), "\[IndentingNewLine]", 
    \(DestroyProgressBar[bar_?JavaObjectQ] := 
      JavaBlock[\[IndentingNewLine]SwingUtilities`windowForComponent[bar]@
          dispose[]; \[IndentingNewLine]ReleaseObject[
          bar]\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[">>> javax.swing.ProgressMonitor <<<", "Section"],

Cell[BoxData[{
    \(\(\(ShowProgressMonitor[\[IndentingNewLine]container_:  
          Null, \[IndentingNewLine]message_:  
          Null, \[IndentingNewLine]note_String: "\<Note\>", \
\[IndentingNewLine]min_Integer:  0, \[IndentingNewLine]max_Integer:  100] := 
      Module[\[IndentingNewLine]{monitor}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]monitor = 
          JavaNew["\<javax.swing.ProgressMonitor\>", \
\[IndentingNewLine]container, message, note, min, 
            max]; \[IndentingNewLine]JavaBlock[\[IndentingNewLine]\(monitor@
              setMillisToPopup[
                5000];\)\[IndentingNewLine]]; \[IndentingNewLine]Return[
          monitor]\[IndentingNewLine]]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(InstallJAVA[];\)\), "\[IndentingNewLine]", 
    \(\(\(LoadClass["\<javax.swing.SwingUtilities\>"];\)\(\[IndentingNewLine]\
\)
    \)\), "\[IndentingNewLine]", 
    \(DestroyProgressMonitor[monitor_?JavaObjectQ] := 
      JavaBlock[
        Module[\[IndentingNewLine]{}, \[IndentingNewLine]InstallJAVA[]; \
\[IndentingNewLine]SwingUtilities`windowForComponent[monitor]@
            dispose[]; \[IndentingNewLine]ReleaseObject[
            monitor]\[IndentingNewLine]]]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[">>> javax.swing.ProgressMonitorInputStream <<<", "Section"],

Cell[CellGroupData[{

Cell["End of Package", "Section"],

Cell[BoxData[
    \(End[]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Protect[\ Evaluate[\ $Context\  <> \ "\<*\>"\ ]\ ]\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(\(EndPackage[]\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(Print["\<Finished loading JavaSwing\>"]\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->Automatic,
WindowSize->{811, 640},
WindowMargins->{{Automatic, 96}, {Automatic, 7}},
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 54, 0, 115, "Title"],
Cell[1784, 54, 30, 0, 64, "Subtitle"],
Cell[1817, 56, 141, 5, 90, "Text"],

Cell[CellGroupData[{
Cell[1983, 65, 29, 0, 59, "Section"],
Cell[2015, 67, 1725, 31, 430, "Input",
  InitializationCell->True],
Cell[3743, 100, 94, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[3874, 107, 39, 0, 59, "Section"],
Cell[3916, 109, 174, 3, 30, "Input",
  InitializationCell->True],
Cell[4093, 114, 74, 2, 30, "Input",
  InitializationCell->True],
Cell[4170, 118, 220, 5, 52, "Text"],
Cell[4393, 125, 4603, 89, 1190, "Input",
  InitializationCell->True],
Cell[8999, 216, 101, 2, 30, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[9125, 222, 48, 0, 43, "Subsubsection"],
Cell[9176, 224, 707, 12, 250, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[9920, 241, 30, 0, 43, "Subsubsection"],
Cell[9953, 243, 341, 6, 90, "Input",
  InitializationCell->True],
Cell[10297, 251, 1097, 22, 410, "Input",
  InitializationCell->True],
Cell[11397, 275, 406, 6, 110, "Input",
  InitializationCell->True],
Cell[11806, 283, 187, 3, 50, "Input",
  InitializationCell->True],
Cell[11996, 288, 160, 3, 30, "Input",
  InitializationCell->True],
Cell[12159, 293, 1084, 16, 310, "Input",
  InitializationCell->True],
Cell[13246, 311, 104, 2, 30, "Input",
  InitializationCell->True],
Cell[13353, 315, 106, 2, 30, "Input",
  InitializationCell->True],
Cell[13462, 319, 1776, 33, 450, "Input",
  InitializationCell->True],
Cell[15241, 354, 482, 7, 130, "Input",
  InitializationCell->True],
Cell[15726, 363, 863, 14, 230, "Input",
  InitializationCell->True],
Cell[16592, 379, 425, 8, 110, "Input",
  InitializationCell->True],
Cell[17020, 389, 185, 3, 50, "Input",
  InitializationCell->True],
Cell[17208, 394, 97, 2, 30, "Input",
  InitializationCell->True],
Cell[17308, 398, 355, 7, 90, "Input",
  InitializationCell->True],
Cell[17666, 407, 83, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17798, 415, 56, 1, 59, "Section"],

Cell[CellGroupData[{
Cell[17879, 420, 93, 2, 47, "Subsection",
  InitializationCell->True],
Cell[17975, 424, 361, 8, 130, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[18373, 437, 62, 1, 47, "Subsection"],
Cell[18438, 440, 1462, 30, 375, "Text",
  InitializationCell->True],
Cell[19903, 472, 255, 6, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[20195, 483, 64, 1, 31, "Subsection"],
Cell[20262, 486, 531, 11, 170, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[20830, 502, 69, 1, 31, "Subsection"],
Cell[20902, 505, 162, 6, 71, "Text",
  InitializationCell->True],
Cell[21067, 513, 384, 9, 130, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21500, 528, 38, 0, 59, "Section"],
Cell[21541, 530, 170, 4, 33, "Text"],
Cell[21714, 536, 451, 8, 190, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[22202, 549, 55, 0, 59, "Section"],
Cell[22260, 551, 1402, 28, 490, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[23699, 584, 48, 0, 59, "Section"],
Cell[23750, 586, 324, 7, 130, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[24111, 598, 53, 0, 59, "Section"],
Cell[24167, 600, 104, 2, 30, "Input",
  InitializationCell->True],
Cell[24274, 604, 99, 2, 30, "Input",
  InitializationCell->True],
Cell[24376, 608, 101, 2, 30, "Input",
  InitializationCell->True],
Cell[24480, 612, 105, 2, 30, "Input",
  InitializationCell->True],
Cell[24588, 616, 103, 2, 30, "Input",
  InitializationCell->True],
Cell[24694, 620, 103, 2, 30, "Input",
  InitializationCell->True],
Cell[24800, 624, 112, 2, 30, "Input",
  InitializationCell->True],
Cell[24915, 628, 101, 2, 30, "Input",
  InitializationCell->True],
Cell[25019, 632, 112, 2, 30, "Input",
  InitializationCell->True],
Cell[25134, 636, 103, 2, 30, "Input",
  InitializationCell->True],
Cell[25240, 640, 112, 2, 30, "Input",
  InitializationCell->True],
Cell[25355, 644, 101, 2, 30, "Input",
  InitializationCell->True],
Cell[25459, 648, 111, 2, 30, "Input",
  InitializationCell->True],
Cell[25573, 652, 105, 2, 30, "Input",
  InitializationCell->True],
Cell[25681, 656, 113, 2, 30, "Input",
  InitializationCell->True],
Cell[25797, 660, 109, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[25943, 667, 51, 0, 59, "Section"],
Cell[25997, 669, 661, 13, 270, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[26695, 687, 53, 0, 59, "Section"],
Cell[26751, 689, 1807, 32, 710, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[28595, 726, 49, 0, 59, "Section"],
Cell[28647, 728, 1085, 20, 430, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[29769, 753, 50, 0, 59, "Section"],
Cell[29822, 755, 893, 17, 350, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[30752, 777, 45, 0, 59, "Section"],
Cell[30800, 779, 1427, 27, 530, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[32264, 811, 56, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[32345, 815, 33, 0, 47, "Subsection"],
Cell[32381, 817, 1861, 36, 650, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[34279, 858, 34, 0, 47, "Subsection"],
Cell[34316, 860, 2310, 45, 770, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[36663, 910, 33, 0, 47, "Subsection"],
Cell[36699, 912, 2936, 54, 1050, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[39672, 971, 37, 0, 47, "Subsection"],
Cell[39712, 973, 3049, 56, 1070, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[42798, 1034, 33, 0, 47, "Subsection"],
Cell[42834, 1036, 1930, 37, 670, "Input",
  InitializationCell->True],
Cell[44767, 1075, 1709, 33, 590, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[46513, 1113, 32, 0, 47, "Subsection"],
Cell[46548, 1115, 1850, 35, 630, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[48435, 1155, 36, 0, 47, "Subsection"],
Cell[48474, 1157, 1953, 36, 670, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[50464, 1198, 34, 0, 47, "Subsection"],
Cell[50501, 1200, 1985, 38, 670, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52535, 1244, 46, 0, 59, "Section"],
Cell[52584, 1246, 1178, 23, 450, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[53799, 1274, 52, 0, 59, "Section"],
Cell[53854, 1276, 1258, 24, 450, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[55149, 1305, 48, 0, 59, "Section"],
Cell[55200, 1307, 1248, 23, 470, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[56485, 1335, 51, 0, 59, "Section"],
Cell[56539, 1337, 1272, 24, 470, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[57848, 1366, 66, 0, 59, "Section"],
Cell[57917, 1368, 841, 14, 310, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[58795, 1387, 44, 0, 59, "Section"],
Cell[58842, 1389, 671, 13, 290, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[59550, 1407, 48, 0, 59, "Section"],
Cell[59601, 1409, 680, 13, 290, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[60318, 1427, 45, 0, 59, "Section"],
Cell[60366, 1429, 1203, 23, 470, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[61606, 1457, 49, 0, 59, "Section"],
Cell[61658, 1459, 956, 19, 370, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[62651, 1483, 53, 0, 59, "Section"],
Cell[62707, 1485, 1004, 20, 390, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[63748, 1510, 48, 0, 59, "Section"],
Cell[63799, 1512, 1029, 20, 410, "Input",
  InitializationCell->True],
Cell[64831, 1534, 322, 8, 130, "Input",
  InitializationCell->True],
Cell[65156, 1544, 266, 6, 130, "Input",
  InitializationCell->True],
Cell[65425, 1552, 242, 5, 130, "Input",
  InitializationCell->True],
Cell[65670, 1559, 244, 5, 130, "Input",
  InitializationCell->True],
Cell[65917, 1566, 246, 5, 130, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[66200, 1576, 50, 0, 59, "Section"],
Cell[66253, 1578, 854, 17, 330, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[67144, 1600, 48, 0, 59, "Section"],
Cell[67195, 1602, 860, 18, 330, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[68092, 1625, 49, 0, 59, "Section"],
Cell[68144, 1627, 1055, 20, 390, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[69236, 1652, 50, 0, 59, "Section"],
Cell[69289, 1654, 1336, 26, 490, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[70662, 1685, 46, 0, 59, "Section"],
Cell[70711, 1687, 1837, 36, 670, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[72585, 1728, 47, 0, 59, "Section"],
Cell[72635, 1730, 767, 15, 270, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[73439, 1750, 44, 0, 59, "Section"],
Cell[73486, 1752, 733, 13, 270, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[74256, 1770, 48, 0, 59, "Section"],
Cell[74307, 1772, 719, 12, 270, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[75063, 1789, 56, 0, 59, "Section"],
Cell[75122, 1791, 839, 15, 290, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[75998, 1811, 59, 0, 59, "Section"],
Cell[76060, 1813, 774, 14, 270, "Input",
  InitializationCell->True]
}, Open  ]],
Cell[76849, 1830, 49, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[76923, 1834, 47, 0, 59, "Section"],
Cell[76973, 1836, 1239, 24, 430, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[78249, 1865, 50, 0, 59, "Section"],
Cell[78302, 1867, 1353, 27, 450, "Input",
  InitializationCell->True],
Cell[79658, 1896, 1136, 22, 410, "Input",
  InitializationCell->True],
Cell[80797, 1920, 1421, 29, 490, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[82255, 1954, 51, 0, 59, "Section"],
Cell[82309, 1956, 1080, 20, 330, "Input",
  InitializationCell->True],
Cell[83392, 1978, 1118, 21, 330, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[84547, 2004, 52, 0, 59, "Section"],
Cell[84602, 2006, 890, 17, 350, "Input",
  InitializationCell->True],
Cell[85495, 2025, 5968, 104, 1690, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[91500, 2134, 44, 0, 59, "Section"],
Cell[91547, 2136, 2036, 39, 670, "Input",
  InitializationCell->True]
}, Open  ]],
Cell[93598, 2178, 44, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[93667, 2182, 72, 0, 59, "Section"],
Cell[93742, 2184, 2040, 37, 750, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[95819, 2226, 54, 0, 59, "Section"],
Cell[95876, 2228, 1277, 24, 510, "Input",
  InitializationCell->True]
}, Open  ]],
Cell[97168, 2255, 65, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[97258, 2259, 33, 0, 59, "Section"],
Cell[97294, 2261, 66, 2, 30, "Input",
  InitializationCell->True],
Cell[97363, 2265, 111, 2, 30, "Input",
  InitializationCell->True],
Cell[97477, 2269, 184, 4, 70, "Input",
  InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

